Crate loglite

Crate loglite 

loglite

Simple and lite logging facility with different log levels and only few dependencies

Structs

FileLog
Log instance
GenericLog
GlobalLog
Singleton access to the log
SysLog
VoidLog
Creates a new instance of Logging which voids the data written to Comparable to io::Sink

Enums

Facility
Facility code, indicating source of log
LogLevel
Logging Level

Traits

LogOutput
Logging